@@ -6,8 +6,8 @@ import os
 from rich.logging import RichHandler
 from rich import print
 import typer
-import tomli
 
+from horbach_cli import __version__
 from horbach_cli.libs.common import log_lvl_callback, LOG_LVL
 from horbach_cli import converter, deduplicator
 
@@ -15,9 +15,7 @@ app = typer.Typer(rich_markup_mode="markdown")
 
 
 def version_callback(value: bool):
-    path = os.path.abspath(os.path.join(os.path.dirname(__file__),".."))
-    logging.debug(path)
-    version = tomli.loads(Path(f"{path}/pyproject.toml").read_text(encoding="utf-8"))["tool"]["poetry"]["version"]
+    version = __version__
     if value:
         print(f":speech_balloon: h-cli Version: {version}")
         raise typer.Exit()
